@@ -1,6 +1,25 @@
-# $Header: /usr/local/cvs/JavaServer/perl/Java.pm,v 1.6 2001/07/20 22:39:44 mark Exp $
-# $Revision: 1.6 $
+# $Header: /usr/local/cvs/JavaServer/perl/Java.pm,v 1.12 2001/11/30 19:18:52 mark Exp $
+# $Revision: 1.12 $
 # $Log: Java.pm,v $
+# Revision 1.12  2001/11/30 19:18:52  mark
+# Windows fix
+#
+# Revision 1.11  2001/08/13 18:36:08  mark
+# Make the auth secret stuff work w/Winblows & Krapple by getting rid of
+# '\015' chars @ end of line
+#
+# Revision 1.10  2001/08/02 16:05:14  mark
+# Fix for Windows authentication
+#
+# Revision 1.9  2001/08/01 21:53:08  mark
+# version to 4.1.1
+#
+# Revision 1.8  2001/08/01 21:51:38  mark
+# Fixed generic handling of pulling out instance data from 'java' object
+#
+# Revision 1.7  2001/07/29 21:18:37  mark
+# VERSION up to 4.1
+#
 # Revision 1.6  2001/07/20 22:39:44  mark
 # Allow blank lines for callbacks
 #
@@ -54,7 +73,7 @@ use vars qw ($AUTOLOAD @ISA $VERSION);
 require Exporter;
 @ISA = qw(Exporter);
 
-$VERSION = '4.1';
+$VERSION = '4.2';
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -64,9 +83,6 @@ $VERSION = '4.1';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 
-# NOT COMPATIBLE with any 1.x versions!!!
-my $VERSION = '2.2';
-
 # Extremely cheesy
 use constant PARAMETER_SEPARATOR => "";
 
@@ -131,6 +147,7 @@ sub _init
 		open(AUTH,$attrs{authfile}) or croak("Could not open ".$attrs{authfile}.": $!\n");
 		$authSecret=<AUTH>;
 		close(AUTH);
+		$authSecret =~ s/\015//g;	# clean up input from Winblows
 		chomp($authSecret);
 	}
 
@@ -139,9 +156,10 @@ sub _init
 
 	# Check response
 	my $line = $self->{socket}->getline;
+	$line =~ s/\015//g;	# clean up input from Winblows
 	chomp $line;
 
-	if ($line ne 'OK')
+	unless ($line =~ 'OK')
 	{
 		print "$line\n";
 		exit 1;
@@ -165,9 +183,6 @@ sub _init
 		{
 			croak("Couldn't create event_server socket: $!");
 		}
-
-		# We wanna re-use the event server port in case of restart
-		setsockopt($self->{event_server}, SOL_SOCKET, SO_REUSEADDR, pack("l",1)) or croak "setsockopt: $!";
 	}
 
 	## Tell JavaServer what port we want our events on...
@@ -180,8 +195,8 @@ sub _init
 		my $peer_address;
 		($self->{event_socket}, $peer_address) = $self->{event_server}->accept;
 	
-		my($port, $iaddr) = sockaddr_in($peer_address);
-		$iaddr = inet_ntoa($iaddr);
+		#my($port, $iaddr) = sockaddr_in($peer_address);
+		#$iaddr = inet_ntoa($iaddr);
 		#print STDERR "Event port connexion from $iaddr:$port!\n";
 	
 		# Don't wanna accept any more event_server connexions
@@ -331,6 +346,7 @@ sub send_line
 {
 	my($self,$line) = @_;
 	return if (!$self || !defined($line));
+	print "Sending line: $line\n" if $DEBUG;
 	$self->get_socket->print("$line\n\n");
 }
 	
@@ -584,7 +600,6 @@ sub do_event
 sub DESTROY
 {
 	my($self) = shift;
-	#print STDERR "DES: ",$self->{name},"\n";
 	if ($self->_is_java)
 	{
 		# Entire Java hash going out of scope
@@ -758,11 +773,13 @@ sub _get_in_java
 	my($self,$what) = @_;
 	if ($self->_is_java)
 	{
-		return $self->{$what}
+		return $self if ($what eq 'java' && !$self->{java});
+		return $self->{$what};
 	}
 	else
 	{
-		return $self->{java}->{$what}
+		return $self->{java} if ($what eq 'java');
+		return $self->{java}->{$what};
 	}
 }
 
@@ -781,7 +798,7 @@ sub _set_in_java
 
 sub _is_java
 {
-	shift->{java};
+	shift->{socket};
 }
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
